==> react-lds-8.7.0.tgz: package/es/components/Tabs/ControlledTabs.js <==
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es7.object.get-own-property-descriptors";
import "core-js/modules/es6.symbol";
import "core-js/modules/es6.object.set-prototype-of";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.array.find";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.string.iterator";
import "core-js/modules/es6.map";
import "core-js/modules/es6.string.link";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { keys.push.apply(keys, Object.getOwnPropertySymbols(object)); } if (enumerableOnly) keys = keys.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import isEqual from 'lodash-es/isEqual';
import { getAriaLabel, getTabsClass } from './utils';
import TabLink from './TabLink';

var ControlledTabs =
/*#__PURE__*/
function (_PureComponent) {
  _inherits(ControlledTabs, _PureComponent);

  _createClass(ControlledTabs, null, [{
    key: "getPanelState",
    value: function getPanelState(children) {
      var positionReducer = function positionReducer(acc, curr, i) {
        return _objectSpread({}, acc, _defineProperty({}, "".concat(curr.props.id), i));
      };

      var childrenArray = React.Children.toArray(children);
      var nextState = {
        positions: childrenArray.reduce(positionReducer, {}),
        focusedTab: false,
        length: childrenArray.length
      };
      return nextState;
    }
  }]);

  function ControlledTabs(props) {
    var _this;

    _classCallCheck(this, ControlledTabs);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ControlledTabs).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "onBlur", function (_ref) {
      var currentTarget = _ref.currentTarget;

      /** Workaround to only fire blur when the whole navigation is unfocused */
      setTimeout(function () {
        if (!currentTarget.contains(document.activeElement)) {
          _this.setState({
            focusedTab: false
          });
        }
      }, 0);
    });

    _defineProperty(_assertThisInitialized(_this), "onLinkKeyUp", function (evt) {
      var _assertThisInitialize = _assertThisInitialized(_this),
          linkNodes = _assertThisInitialize.linkNodes;

      var key = evt.key;
      var isLeftKey = key === 'ArrowLeft';
      var isRightKey = key === 'ArrowRight';
      if (!isLeftKey && !isRightKey) return;
      var length = _this.state.length;

      var currentPosition = _this.getCurrentPosition();
      /* eslint-disable no-nested-ternary */


      var nextIndex = isLeftKey ? currentPosition > 0 ? currentPosition - 1 : Math.max(length - 1, 0) : currentPosition < length - 1 ? currentPosition + 1 : 0;
      /* eslint-enable */

      var nextId = _this.getIdForPosition(nextIndex);

      _this.onChangeTab(nextId);
      /** Accesses the ref defined in <TabLink /> */


      var linkNode = linkNodes.get(nextId);

      if (linkNode && linkNode.link) {
        linkNode.link.focus();
      }
    });

    _defineProperty(_assertThisInitialized(_this), "renderLink", function (child) {
      var focusedTab = _this.state.focusedTab;
      var _this$props = _this.props,
          activeTab = _this$props.activeTab,
          scoped = _this$props.scoped;
      var _child$props = child.props,
          id = _child$props.id,
          renderTitle = _child$props.renderTitle,
          title = _child$props.title;
      var isActive = activeTab === id;
      var isFocused = focusedTab === id;
      return React.createElement(TabLink, {
        isActive: isActive,
        isFocused: isFocused,
        id: id,
        onFocus: _this.getOnLinkFocus(id),
        onKeyUp: _this.onLinkKeyUp
        /* Focus is triggered before click but after mouseDown, using mouseDown to prevent a render-cycle */
        ,
        onMouseDown: _this.getOnLinkClick(id),
        ref: _this.getLinkRefSetter(id),
        scoped: scoped,
        title: title
      }, renderTitle ? renderTitle({
        id: id,
        isActive: isActive,
        isFocused: isFocused,
        title: title
      }) : title);
    });

    _defineProperty(_assertThisInitialized(_this), "renderActiveTab", function (child) {
      var _this$props2 = _this.props,
          activeTab = _this$props2.activeTab,
          renderInactiveTabs = _this$props2.renderInactiveTabs,
          scoped = _this$props2.scoped;
      var id = child.props.id;
      var isActive = id === activeTab;
      var hideTab = !isActive && !renderInactiveTabs;
      return React.cloneElement(child, {
        'aria-labelledby': getAriaLabel(child.props.id),
        isActive: hideTab ? null : isActive,
        scoped: scoped
      });
    });

    _this.state = ControlledTabs.getPanelState(props.children);
    /** refs are used to focus links after keyboard navigation occured */

    _this.linkNodes = new Map();
    return _this;
  }

  _createClass(ControlledTabs, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(_ref2) {
      var nextChildren = _ref2.children;
      var positions = this.state.positions;
      var nextChildrenArr = React.Children.toArray(nextChildren);
      var prevChildrenArr = React.Children.toArray(this.children);
      var isEqualLength = nextChildrenArr.length !== prevChildrenArr.length;
      var nextState = ControlledTabs.getPanelState(nextChildrenArr);

      if (!isEqualLength || !isEqual(nextState.positions, positions)) {
        this.setState(nextState);
      }
    }
  }, {
    key: "onChangeTab",
    value: function onChangeTab(nextActiveTab) {
      var _this$props3 = this.props,
          activeTab = _this$props3.activeTab,
          onChangeTab = _this$props3.onChangeTab;

      if (nextActiveTab !== activeTab) {
        this.setState({
          focusedTab: nextActiveTab
        });
        onChangeTab(nextActiveTab);
      }
    }
  }, {
    key: "getCurrentPosition",
    value: function getCurrentPosition() {
      var activeTab = this.props.activeTab;
      var positions = this.state.positions;
      return positions[activeTab];
    }
  }, {
    key: "getIdForPosition",
    value: function getIdForPosition(position) {
      var positions = this.state.positions;
      return Object.keys(positions).find(function (key) {
        return positions[key] === position;
      });
    }
  }, {
    key: "getLinkRefSetter",
    value: function getLinkRefSetter(id) {
      var _this2 = this;

      return function (c) {
        _this2.linkNodes.set(id, c);
      };
    }
  }, {
    key: "getOnLinkFocus",
    value: function getOnLinkFocus(id) {
      var _this3 = this;

      return function () {
        _this3.setState({
          focusedTab: id
        });
      };
    }
  }, {
    key: "getOnLinkClick",
    value: function getOnLinkClick(id) {
      var _this4 = this;

      return function (evt) {
        evt.stopPropagation();

        _this4.onChangeTab(id);
      };
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props4 = this.props,
          children = _this$props4.children,
          scoped = _this$props4.scoped,
          size = _this$props4.size,
          styled = _this$props4.styled;
      var sldsClasses = [getTabsClass('', scoped), {
        'slds-tabs_card': styled
      }, _defineProperty({}, "slds-tabs_".concat(size), size)];
      return React.createElement("div", {
        className: cx(sldsClasses)
      }, React.createElement("ul", {
        className: getTabsClass('__nav', scoped),
        onBlur: this.onBlur,
        role: "tablist"
      }, React.Children.map(children, this.renderLink)), React.Children.map(children, this.renderActiveTab));
    }
  }]);

  return ControlledTabs;
}(PureComponent);

_defineProperty(ControlledTabs, "defaultProps", {
  renderInactiveTabs: false,
  scoped: false,
  size: null,
  styled: false
});

ControlledTabs.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Id of the currently active tab
   */
  activeTab: PropTypes.string.isRequired,

  /**
   * One or more Tab components
   */
  children: PropTypes.node.isRequired,

  /**
   * Callback triggered when the Tab is changed. Receives (nextIndex)
   */
  onChangeTab: PropTypes.func.isRequired,

  /**
   * When this is true, inActive tabs will be rendered and hidden with .slds-hide instead of returning null
   */
  renderInactiveTabs: PropTypes.bool,

  /**
   * Renders scoped variant
   */
  scoped: PropTypes.bool,

  /**
   * Size modifier
   */
  size: PropTypes.oneOf(['medium', 'large']),

  /**
   * Renders Card-like variant
   */
  styled: PropTypes.bool
} : {};
export default ControlledTabs;

==> react-lds-9.0.2.tgz: package/es/components/Tabs/ControlledTabs.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.filter";
import "core-js/modules/es.array.find";
import "core-js/modules/es.array.for-each";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.array.map";
import "core-js/modules/es.array.reduce";
import "core-js/modules/es.map";
import "core-js/modules/es.object.get-own-property-descriptor";
import "core-js/modules/es.object.get-own-property-descriptors";
import "core-js/modules/es.object.get-prototype-of";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.set-prototype-of";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.string.iterator";
import "core-js/modules/es.string.link";
import "core-js/modules/web.dom-collections.for-each";
import "core-js/modules/web.dom-collections.iterator";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import isEqual from 'lodash-es/isEqual';
import { getAriaLabel, getTabsClass } from './utils';
import TabLink from './TabLink';

var ControlledTabs =
/*#__PURE__*/
function (_PureComponent) {
  _inherits(ControlledTabs, _PureComponent);

  _createClass(ControlledTabs, null, [{
    key: "getPanelState",
    value: function getPanelState(children) {
      var positionReducer = function positionReducer(acc, curr, i) {
        return _objectSpread({}, acc, _defineProperty({}, "".concat(curr.props.id), i));
      };

      var childrenArray = React.Children.toArray(children);
      var nextState = {
        positions: childrenArray.reduce(positionReducer, {}),
        focusedTab: false,
        length: childrenArray.length
      };
      return nextState;
    }
  }]);

  function ControlledTabs(props) {
    var _this;

    _classCallCheck(this, ControlledTabs);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ControlledTabs).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "onBlur", function (_ref) {
      var currentTarget = _ref.currentTarget;

      /** Workaround to only fire blur when the whole navigation is unfocused */
      setTimeout(function () {
        if (!currentTarget.contains(document.activeElement)) {
          _this.setState({
            focusedTab: false
          });
        }
      }, 0);
    });

    _defineProperty(_assertThisInitialized(_this), "onLinkKeyUp", function (evt) {
      var _assertThisInitialize = _assertThisInitialized(_this),
          linkNodes = _assertThisInitialize.linkNodes;

      var key = evt.key;
      var isLeftKey = key === 'ArrowLeft';
      var isRightKey = key === 'ArrowRight';
      if (!isLeftKey && !isRightKey) return;
      var length = _this.state.length;

      var currentPosition = _this.getCurrentPosition();
      /* eslint-disable no-nested-ternary */


      var nextIndex = isLeftKey ? currentPosition > 0 ? currentPosition - 1 : Math.max(length - 1, 0) : currentPosition < length - 1 ? currentPosition + 1 : 0;
      /* eslint-enable */

      var nextId = _this.getIdForPosition(nextIndex);

      _this.onChangeTab(nextId);
      /** Accesses the ref defined in <TabLink /> */


      var linkNode = linkNodes.get(nextId);

      if (linkNode && linkNode.link) {
        linkNode.link.focus();
      }
    });

    _defineProperty(_assertThisInitialized(_this), "renderLink", function (child) {
      var focusedTab = _this.state.focusedTab;
      var _this$props = _this.props,
          activeTab = _this$props.activeTab,
          scoped = _this$props.scoped;
      var _child$props = child.props,
          id = _child$props.id,
          renderTitle = _child$props.renderTitle,
          title = _child$props.title;
      var isActive = activeTab === id;
      var isFocused = focusedTab === id;
      return React.createElement(TabLink, {
        isActive: isActive,
        isFocused: isFocused,
        id: id,
        onFocus: _this.getOnLinkFocus(id),
        onKeyUp: _this.onLinkKeyUp
        /* Focus is triggered before click but after mouseDown, using mouseDown to prevent a render-cycle */
        ,
        onMouseDown: _this.getOnLinkClick(id),
        ref: _this.getLinkRefSetter(id),
        scoped: scoped,
        title: title
      }, renderTitle ? renderTitle({
        id: id,
        isActive: isActive,
        isFocused: isFocused,
        title: title
      }) : title);
    });

    _defineProperty(_assertThisInitialized(_this), "renderActiveTab", function (child) {
      var _this$props2 = _this.props,
          activeTab = _this$props2.activeTab,
          renderInactiveTabs = _this$props2.renderInactiveTabs,
          scoped = _this$props2.scoped;
      var id = child.props.id;
      var isActive = id === activeTab;
      var hideTab = !isActive && !renderInactiveTabs;
      return React.cloneElement(child, {
        'aria-labelledby': getAriaLabel(child.props.id),
        isActive: hideTab ? null : isActive,
        scoped: scoped
      });
    });

    _this.state = ControlledTabs.getPanelState(props.children);
    /** refs are used to focus links after keyboard navigation occured */

    _this.linkNodes = new Map();
    return _this;
  }

  _createClass(ControlledTabs, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(_ref2) {
      var nextChildren = _ref2.children;
      var positions = this.state.positions;
      var nextChildrenArr = React.Children.toArray(nextChildren);
      var prevChildrenArr = React.Children.toArray(this.children);
      var isEqualLength = nextChildrenArr.length !== prevChildrenArr.length;
      var nextState = ControlledTabs.getPanelState(nextChildrenArr);

      if (!isEqualLength || !isEqual(nextState.positions, positions)) {
        this.setState(nextState);
      }
    }
  }, {
    key: "onChangeTab",
    value: function onChangeTab(nextActiveTab) {
      var _this$props3 = this.props,
          activeTab = _this$props3.activeTab,
          onChangeTab = _this$props3.onChangeTab;

      if (nextActiveTab !== activeTab) {
        this.setState({
          focusedTab: nextActiveTab
        });
        onChangeTab(nextActiveTab);
      }
    }
  }, {
    key: "getCurrentPosition",
    value: function getCurrentPosition() {
      var activeTab = this.props.activeTab;
      var positions = this.state.positions;
      return positions[activeTab];
    }
  }, {
    key: "getIdForPosition",
    value: function getIdForPosition(position) {
      var positions = this.state.positions;
      return Object.keys(positions).find(function (key) {
        return positions[key] === position;
      });
    }
  }, {
    key: "getLinkRefSetter",
    value: function getLinkRefSetter(id) {
      var _this2 = this;

      return function (c) {
        _this2.linkNodes.set(id, c);
      };
    }
  }, {
    key: "getOnLinkFocus",
    value: function getOnLinkFocus(id) {
      var _this3 = this;

      return function () {
        _this3.setState({
          focusedTab: id
        });
      };
    }
  }, {
    key: "getOnLinkClick",
    value: function getOnLinkClick(id) {
      var _this4 = this;

      return function (evt) {
        evt.stopPropagation();

        _this4.onChangeTab(id);
      };
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props4 = this.props,
          children = _this$props4.children,
          scoped = _this$props4.scoped,
          size = _this$props4.size,
          styled = _this$props4.styled;
      var sldsClasses = [getTabsClass('', scoped), {
        'slds-tabs_card': styled
      }, _defineProperty({}, "slds-tabs_".concat(size), size)];
      return React.createElement("div", {
        className: cx(sldsClasses)
      }, React.createElement("ul", {
        className: getTabsClass('__nav', scoped),
        onBlur: this.onBlur,
        role: "tablist"
      }, React.Children.map(children, this.renderLink)), React.Children.map(children, this.renderActiveTab));
    }
  }]);

  return ControlledTabs;
}(PureComponent);

_defineProperty(ControlledTabs, "defaultProps", {
  renderInactiveTabs: false,
  scoped: false,
  size: null,
  styled: false
});

ControlledTabs.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Id of the currently active tab
   */
  activeTab: PropTypes.string.isRequired,

  /**
   * One or more Tab components
   */
  children: PropTypes.node.isRequired,

  /**
   * Callback triggered when the Tab is changed. Receives (nextIndex)
   */
  onChangeTab: PropTypes.func.isRequired,

  /**
   * When this is true, inActive tabs will be rendered and hidden with .slds-hide instead of returning null
   */
  renderInactiveTabs: PropTypes.bool,

  /**
   * Renders scoped variant
   */
  scoped: PropTypes.bool,

  /**
   * Size modifier
   */
  size: PropTypes.oneOf(['medium', 'large']),

  /**
   * Renders Card-like variant
   */
  styled: PropTypes.bool
} : {};
export default ControlledTabs;
